@@ -1,6 +1,6 @@
 package Net::DNS::Nameserver;
 #
-# $Id: Nameserver.pm 749 2008-12-19 15:20:22Z olaf $
+# $Id: Nameserver.pm 835 2009-12-29 20:20:38Z olaf $
 #
 
 use Net::DNS;
@@ -23,7 +23,7 @@ use constant	STATE_ACCEPTED => 1;
 use constant	STATE_GOT_LENGTH => 2;
 use constant	STATE_SENDING => 3;
 
-$VERSION = (qw$LastChangedRevision: 749 $)[1];
+$VERSION = (qw$LastChangedRevision: 835 $)[1];
 
 
 
@@ -60,7 +60,8 @@ sub new {
 	my @localaddresses = $resolver->nameservers(@LocalAddr);
 
 	my $port = $self{LocalPort} || DEFAULT_PORT;
-
+	$self{Truncate}=1 unless defined ($self{Truncate});
+	
 	my @sock_tcp;	# All the TCP sockets we will listen to.
 	my @sock_udp;	# All the UDP sockets we will listen to.
 
@@ -221,9 +222,9 @@ sub make_reply {
 		$reply->header->aa(1) if $headermask->{'aa'};
 		$reply->header->ra(1) if $headermask->{'ra'};
 		$reply->header->ad(1) if $headermask->{'ad'};
-		if (defined $Net::DNS::opcodesbyname{$headermask->{'opcode'}}){
-			$reply->header->opcode( $headermask->{'opcode'} );
-		}
+		$reply->header->opcode( $headermask->{'opcode'} ) if
+		  ($headermask->{'opcode'} &&
+		   defined $Net::DNS::opcodesbyname{$headermask->{'opcode'}});
 	}
 	
 	
@@ -348,7 +349,13 @@ sub udp_connection {
 
  	$sock->recv($buf, &Net::DNS::PACKETSZ);
  	my ($peerhost,$peerport,$sockhost) = ($sock->peerhost, $sock->peerport, $sock->sockhost);
+	unless (defined $peerhost && defined $peerport){
+		print "the Peer host and sock host appear to be undefined: bailing out of handling the UDP connection" if $self->{"Verbose"};
+		return;
+	}
 	
+
+
  	print "UDP connection from $peerhost:$peerport to $sockhost\n" if $self->{"Verbose"};
 
 	my $query = Net::DNS::Packet->new(\$buf);
@@ -359,12 +366,13 @@ sub udp_connection {
 		    peerport => $sock->peerport
 		   };
 	my $reply = $self->make_reply($query, $peerhost, $conn) || return;
-	my $reply_data = $reply->data;
-
+	my $max_len = $self->max_udp_len($query);
+ 	print "Maximum reply length as advertosed in EDNS from $peerhost:$peerport: $max_len\n" if $self->{"Verbose"};
+	$reply->truncate($max_len) if $self->{Truncate};
 	local $| = 1 if $self->{"Verbose"};
 	print "Writing response - " if $self->{"Verbose"};
 
-	if ($sock->send($reply_data)) { # 
+	if ($sock->send($reply->data)) { # 
 	  print "done\n" if $self->{"Verbose"};
 	}
 	else {
@@ -373,6 +381,17 @@ sub udp_connection {
       }
 
 
+sub max_udp_len {
+	my ($self, $query) = @_;
+
+	for my $rr ($query->additional) {
+		return $rr->size if $rr->type eq 'OPT';
+	}
+
+	return 512;
+}
+
+
 sub get_open_tcp {
     my $self=shift;
     return keys %{$self->{"_tcp"}};
@@ -393,9 +412,10 @@ sub get_open_tcp {
 
 sub loop_once {
   my ($self, $timeout) = @_;
-  $timeout=0 unless defined($timeout);
-  print ";loop_once called with $timeout \n" if $self->{"Verbose"} >4;
+
+  print ";loop_once called with timeout: ".defined($timeout)?$timeout:"undefined"."\n" if $self->{"Verbose"} >4;
   foreach my $sock (keys %{$self->{"_tcp"}}) {
+      # There is TCP traffic to handle
       $timeout = 0.1 if $self->{"_tcp"}{$sock}{"outbuffer"};
   }
   my @ready = $self->{"select"}->can_read($timeout);
@@ -519,7 +539,8 @@ objects.  See L</EXAMPLE> for an example.
 	LocalAddr	 => ['::1' , '127.0.0.1' ],
 	LocalPort	 => "5353",
 	ReplyHandler => \&reply_handler,
-	Verbose		 => 1
+	Verbose		 => 1,
+        Truncate         => 0,
  );
 
 Creates a nameserver object.  Attributes are:
@@ -533,7 +554,8 @@ Creates a nameserver object.  Attributes are:
                         opdcode NS_NOTIFY (RFC1996)
   Verbose		Print info about received 
 			queries.			Defaults to 0 (off).
-
+  Truncate              Truncates UDP packets that
+                        are to big for the reply        Defaults to 1 (on)
 
 The LocalAddr attribute may alternatively be specified as a list of IP
 addresses to listen to. 
@@ -572,6 +594,14 @@ Unix-like systems, the program will probably have to run as root
 to listen on the default port, 53.	A non-privileged user should
 be able to listen on ports 1024 and higher.
 
+Packet Truncation is new functionality for
+$Net::DNS::Nameserver::VERSION>830 and uses the
+Net::DNS::Packet::truncate method with a size determinde by the
+advertised EDNS0 size in the query, or 512 if EDNS0 is not advertised
+in the query. Only UDP replies are truncated. If you want to do packet
+runcation yourself you should set Truncate to 0 and use the truncate
+method on the reply packet in the code you use for the ReplyHandler.
+
 Returns a Net::DNS::Nameserver object, or undef if the object
 couldn't be created.
 
@@ -585,10 +615,6 @@ Start accepting queries. Calling main_loop never returns.
 
 =cut
 
-#####
-#
-#  The functionality might change. Left "undocumented" for now.
-#
 =head2 loop_once
 
 	$ns->loop_once( [TIMEOUT_IN_SECONDS] );
@@ -697,7 +723,7 @@ Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
-Portions Copyright (c) 2005-2007 O.M, Kolkman, RIPE NCC.
+Portions Copyright (c) 2005-2009 O.M, Kolkman, RIPE NCC.
  
 Portions Copyright (c) 2005 Robert Martin-Legene.
 
