@@ -1,12 +1,44 @@
 package Net::DNS::RR::NAPTR;
 #
-# $Id: NAPTR.pm 219 2005-03-03 14:18:10Z olaf $
+# $Id: NAPTR.pm 801 2009-10-02 16:02:37Z olaf $
 #
 use strict;
+BEGIN { 
+    eval { require bytes; }
+} 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 219 $)[1];
+$VERSION = (qw$LastChangedRevision: 801 $)[1];
+
+
+
+
+__PACKAGE__->set_rrsort_func("order",
+			       sub {
+				   my ($a,$b)=($Net::DNS::a,$Net::DNS::b);
+				   $a->{'order'} <=> $b->{'order'}
+				   ||
+				       $a->{'preference'} <=> $b->{'preference'}
+}
+);
+
+
+__PACKAGE__->set_rrsort_func("default_sort",
+			       __PACKAGE__->get_rrsort_func("order")
+
+    );
+
+__PACKAGE__->set_rrsort_func("preference",
+			       sub {
+				   my ($a,$b)=($Net::DNS::a,$Net::DNS::b);
+				   $a->{"preference"} <=> $b->{"preference"}
+				   ||
+				       $a->{"order"} <=> $b->{"order"}
+}
+);
+
+
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -44,20 +76,18 @@ sub new_from_string {
 
 	if ($string && $string =~ /^      (\d+)      \s+
 				          (\d+)      \s+
-				     ['"] (.*?) ['"] \s+
-				     ['"] (.*?) ['"] \s+
-				     ['"] (.*?) ['"] \s+
-				          (\S+) $/x) {
+				     (['"]) (.*?) \3 \s+
+				     (['"]) (.*?) \5 \s+
+				     (['"]) (.*?) \7 \s+
+				          (\S+) $/xo) {
 
 		$self->{"order"}       = $1;
 		$self->{"preference"}  = $2;
-		$self->{"flags"}       = $3;
-		$self->{"service"}     = $4;
-		$self->{"regexp"}      = $5;
-		$self->{"replacement"} = $6;
-		$self->{"replacement"} =~ s/\.+$//;
+		$self->{"flags"}       = $4;
+		$self->{"service"}     = $6;
+		$self->{"regexp"}      = $8;
+		$self->{"replacement"} = Net::DNS::stripdot($9);
 	}
-
 	return bless $self, $class;
 }
 
@@ -97,13 +127,22 @@ sub rr_rdata {
 		$rdata .= pack("C", length $self->{"regexp"});
 		$rdata .= $self->{"regexp"};
 
-		$rdata .= $packet->dn_comp($self->{"replacement"},
-					   $offset + length $rdata);
-	}
+		$rdata .= $self->_name2wire ($self->{"replacement"});
+
+	      }
 
 	return $rdata;
 }
 
+
+sub _normalize_dnames {
+	my $self=shift;
+	$self->_normalize_ownername();
+	$self->{'replacement'}=Net::DNS::stripdot($self->{'replacement'}) if defined $self->{'replacement'};
+}
+
+
+
 1;
 __END__
 
@@ -162,6 +201,7 @@ Returns the replacement field.
 Copyright (c) 1997-2002 Michael Fuhr. 
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
+Portions Copyright (c) 2005 Olaf Kolkman NLnet Labs.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
