@@ -1,15 +1,18 @@
 package Net::DNS::RR::OPT;
 #
-# $Id: OPT.pm 102 2004-08-12 05:16:06Z ctriv $
+# $Id: OPT.pm 803 2009-11-20 11:35:04Z olaf $
 #
 
 use strict;
+BEGIN { 
+    eval { require bytes; }
+} 
 use vars qw(@ISA $VERSION %extendedrcodesbyname %extendedrcodesbyval $EDNSVERSION);
 
 use Carp;
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 102 $)[1];
+$VERSION = (qw$LastChangedRevision: 803 $)[1];
 
 $EDNSVERSION = 0;
 
@@ -61,6 +64,7 @@ sub new {
 
 
 
+
 sub new_from_string {
     my ($class, $self ) = @_;
     
@@ -104,6 +108,7 @@ sub new_from_hash {
 
 
 
+
 sub string {
    my $self = shift;
    return
@@ -137,6 +142,44 @@ sub rr_rdata {
 }
 
 
+
+
+
+
+
+sub do{
+    my $self=shift;
+    return ( 0x8000 & $self->{"ednsflags"} );
+}
+
+
+
+sub set_do{
+    my $self=shift;
+    return $self->{"ednsflags"} = ( 0x8000 | $self->{"ednsflags"} );
+
+}
+
+
+
+sub clear_do{
+    my $self=shift;
+    return $self->{"ednsflags"} = ( ~0x8000 & $self->{"ednsflags"} );
+
+}
+
+
+
+sub size {
+    my $self=shift;
+    my $size=shift;
+    $self->{"class"}=$size if defined($size);
+    return $self->{"class"};
+}
+
+
+
+
 1;
 __END__
 
@@ -165,15 +208,15 @@ RR from string.
 One may create the object from a hash. See RFC 2671 for details for
 the meaning of the hash keys.
 
- $rr= new Net::DNS::RR {
-    name => "",     # Ignored and set to ""
+ $rr= Net::DNS::RR->new (
+    name => "",                # Ignored and set to ""
     type => "OPT",  
-    class => 1024,    # sets UDP payload size
+    class => 1024,             # sets UDP payload size
     extendedrcode =>  0x00,    # sets the extended RCODE 1 octets
     ednsflags     =>  0x0000,  # sets the ednsflags (2octets)  
-    optioncode   =>   0x0      # 2 octets
+    optioncode   =>   0x0,     # 2 octets
     optiondata   =>   0x0      # optionlength octets
- }    
+ );
 
 The ednsversion is set to 0 for now. The ttl value is determined from 
 the extendedrcode, the ednsversion and the ednsflag.
@@ -185,6 +228,21 @@ If optioncode is left undefined then we do not expect any RDATA.
 The defaults are no rdata.   
 
 
+=head2 do, set_do, clear_do
+
+    $opt->set_do;
+
+Reads, sets and clears the do flag. (first bit in the ednssflags);
+
+
+=head2 size
+
+    $opt->size(1498);
+    print "Packet size:". $opt->size() ;
+ 
+Sets or gets the packet size.
+
+
 =head1 TODO
 
 - This class is tailored to use with dnssec. 
